#
# spec file for package libnumbertext
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{!?make_build:%global make_build make %{?_smp_mflags}}
%define libname libnumbertext-1_0-0
Name:           libnumbertext
Version:        1.0.11
Release:        1.7
Summary:        Language-neutral NUMBERTEXT and MONEYTEXT functions
License:        MPL-2.0
URL:            https://github.com/Numbertext/libnumbertext
Source:         https://github.com/Numbertext/libnumbertext/archive/%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  pkgconfig
%if 0%{?suse_version} < 1500
BuildRequires:  gcc7-c++
%endif

%description
Language-neutral NUMBERTEXT and MONEYTEXT functions for LibreOffice Calc

%package -n %{libname}
Summary:        Language-neutral NUMBERTEXT and MONEYTEXT functions
Requires:       %{name}-data >= %{version}

%description -n %{libname}
Language-neutral NUMBERTEXT and MONEYTEXT functions for LibreOffice Calc

%package devel
Summary:        Files for Developing with libnumbertext
Requires:       %{libname} = %{version}

%description devel
Language-neutral NUMBERTEXT and MONEYTEXT functions for LibreOffice Calc

This package contains the libnumbertext development files.

%package tools
Summary:        Tools to work with NUMBERTEXT and MONEYTEXT functions
Requires:       %{name}-data >= %{version}

%description tools
This package contains tools to work with NUMBERTEXT and MONEYTEXT functions

%package data
Summary:        Language data for numbertext

%description data
This package contains data providing information for localized nubertext
conversions.

%prep
%setup -q

%build
autoreconf -fvi
%if 0%{?suse_version} < 1500
export CXX=g++-7
%endif
%configure \
	--disable-static \
	--disable-silent-rules \
	%{nil}
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
# missing config.h header
install -m 0644 src/config.h %{buildroot}%{_includedir}/libnumbertext/config.h

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%license COPYING
%{_libdir}/*.so.*

%files devel
%dir %{_includedir}/libnumbertext
%{_includedir}/libnumbertext/*
%{_libdir}/libnumbertext-1.0.so
%{_libdir}/pkgconfig/libnumbertext.pc

%files tools
%{_bindir}/spellout

%files data
%dir %{_datadir}/libnumbertext
%{_datadir}/libnumbertext/*.sor

%changelog
* Sat Jan  7 2023 Dirk Müller <dmueller@suse.com>
- update to 1.0.11:
  * Soros.cxx/java/js/py: fix boundary inheritance of
  * optional function (conditional text), reported by Juanma Sanchez
  * and Antonio Bueno
  * test/*, configure.ac, Makefile.am: add C++ unit testing
  * Soros.cxx: fix an assert seen with in libreoffice crashtesting on
  * an empty string, by Caolán McNamara
  * New modules:
  * fa.sor: new Persian (Farsi) module by Amir Hossein Maher
  * mul.sor: new module with note symbols for multiple languages
  * Module fixes and extensions:
  * ca.sor: revert removing conditional text
  * cs.sor: fix ordinals, cardinals, currencies by Stanislav Horáček,
  * with help of Zdeněk Crhonek
  * da.sor: revert removing conditional text
  * en.sor: add extra currencies (BZF, DKK, ILS, LKR, ZMW, ZWD) for
  * LibreOffice locales of Number Format dialog windows
  * es.sor: add extra currencies (PAB, SVC, VED/VES) for LibreOffice,
  * revert removing conditional text
  * ga.sor: add currency support
  * hu_Hung.sor: fix regression of transliteration of parenthesized words
  * in LibreOffice, reported by Zoltán Óvári
  * ro.sor: strip first space and remove double space in currency
  * ru.sor: fix grammar of cents by Alex Ivanov
  * sl.sor: fix cardinal-masculine and cardinal-neuter,
  * reported by Martin Srebotnjak
  * uk.sor: fix grammar of cents by Alex Ivanov
  * LibreOffice Calc add-on:
  * CalcAddIn.xcu: new Russian translation by Evgeniy Kukhtinov
* Sun Apr 10 2022 Dirk Müller <dmueller@suse.com>
- update to 1.0.10:
  * hu_Hung.sor: fix regression of transliteration on Windows
  - non-BMP characters aren't supported in bracket expressions in regex of MS Visual C++,
    resulting missing transliteration on Windows. Replaced by branches separated by |.
  * hu_Hung.sor: fix regression of transliteration of punctuation marks
* Fri Feb 11 2022 Dirk Müller <dmueller@suse.com>
- update to 1.0.8:
  * src/Soros.py: fix FutureWarning: Possible nested set at position, reported by Rene Engelhard
  * fr.sor:
  - use hyphens instead of spaces, e.g. cent-deux, reported by "4560041" at GitHub
  - new prefix "informal" for 1100–1900 (onze-cents - dix-neuf-cents)
  - add prefix "feminine" and "masculine" (1 -> une/un), bug reports by arena94 at GitGub
  * hu_Hung.sor:
  - fix transliteration of old Hungarian family names, bug report by Zoltán Óvári
  - fix 100–199, 1000–1999, 1000000–1999999 and 1000000000–1999999999 (bad ordering)
  – fix conversion of single letters "í", "Í" and "NY";
  - fix unnecessary conversion of words ending with "q", e.g. "IQ";
  - fix unnecessary conversion of words not ending with unknown letters
  * mr.sor: Marathi spelling corrections by Shantanu Oak
  * pl.sor: fix ordinal 20-29, reported by Gabryha at GitHub
  * uk.sor, CalcAddIn.xcu, description.xml.in: fix spell by Olexandr Nesterenko
  - replace apostrophe symbol to U+02BC, reported by Volodymyr Lisivka
  - up number to 10^42
  - add cardinal, update help
  - add uk locale
  * zh.sor: add ordinal numbers, use always 二 for 2, reported by Ming-Hua
* Wed May 19 2021 Fridrich Strba <fstrba@suse.com>
- Define conditionally make_build to fix build on systems that do
  not have that macro
* Sat Mar 13 2021 Dirk Müller <dmueller@suse.com>
- update to 1.0.7:
  * ga.sor: new module Irish by László Németh
  * lg.sor: new module Luganda by Phillip Samuel
  * mr.sor: new module Marathi by Ankur Heramb Joshi
  * mt.sor: new module Maltase by László Németh
  * fi.sor: fix ordinal 0, bug report by Tuomas Hietala
  * hu_Hung.sor:
  - fix transliteration of Vörösmarty, bug report by Zoltán Óvári
  - replace ü and ű by Viktor Kovács
  - fix transliteration of dates with affixation
  * th.sor: fix big (>999,999) numbers by Vladislav Kiper
  * ua.sor: fix euro cent, bug report by Kty0mka
* Thu Jun 18 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.0.6:
  * minor fixes and fuzzer fixes
* Mon Oct 29 2018 Tomáš Chvátal <tchvatal@suse.com>
- Drop libnumbertext-boost.patch and rather rely on new gcc, safer
* Mon Oct 29 2018 Tomáš Chvátal <tchvatal@suse.com>
- Add patch libnumbertext-boost.patch to fix build with boost
  and enable build on older distributions
* Tue Oct 16 2018 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.0.5:
  * Various fixes in numerical calculations and issues reported on
    libreoffice tracker
- Drop merged libnumbertext-oldgcc.patch
* Mon Jun  4 2018 tchvatal@suse.com
- Add patch to build on old gcc versions:
  * libnumbertext-oldgcc.patch
* Wed May 30 2018 tchvatal@suse.com
- Add config.h to installed headers as all headers require it
* Wed May 30 2018 tchvatal@suse.com
- Initial commit, needed by libreoffice
